@@ -68,20 +68,20 @@ static gboolean ftype_dialog_key_press(GtkWidget *widget,GdkEventKey *event,
 
 gboolean ftype_dialog(gint *pos)
 {
-	gchar *text=N_("ե륿פʤ");
+	gchar *text=N_("Independent File Type");
 	gint i;
 	GtkWidget *dialog,*clist,*scroll,*hbox,*vbox,*button1;
 
 	/* ᥤ󥦥ɥ */
 	dialog=gtk_window_new(GTK_WINDOW_DIALOG);
-	gtk_window_set_title(GTK_WINDOW(dialog),_("ե륿פɤ߹"));
+	gtk_window_set_title(GTK_WINDOW(dialog),_("Associating File Type"));
 	gtk_window_set_default_size(GTK_WINDOW(dialog),320,240);
 	gtk_signal_connect_after(GTK_OBJECT(dialog),"key-press-event",
 								GTK_SIGNAL_FUNC(ftype_dialog_key_press),NULL);
 	gtk_signal_connect(GTK_OBJECT(dialog),"destroy",gtk_main_quit,NULL);
 	/* ܥ */
-	button0=gtk_button_new_with_label(_("λ"));
-	button1=gtk_button_new_with_label(_(""));
+	button0=gtk_button_new_with_label(_("OK"));
+	button1=gtk_button_new_with_label(_("Cancel"));
 	gtk_signal_connect(GTK_OBJECT(button0),"clicked",
 											ftype_dialog_clicked_ok,dialog);
 	gtk_signal_connect_object(GTK_OBJECT(button1),"clicked",
@@ -90,8 +90,7 @@ gboolean ftype_dialog(gint *pos)
 	GTK_WIDGET_SET_FLAGS(button1,GTK_CAN_DEFAULT);
 	/* ꥹȥܥå */
 	clist=gtk_clist_new(1);
-	gtk_clist_set_column_title(GTK_CLIST(clist),0,
-											_("ϿƤե륿"));
+	gtk_clist_set_column_title(GTK_CLIST(clist),0,_("Registered File Type"));
 	gtk_clist_column_titles_show(GTK_CLIST(clist));
 	gtk_clist_column_titles_passive(GTK_CLIST(clist));
 	for (i=0;i<ftnum;i++)
