@@ -118,38 +118,38 @@ void set_menu_bar(TEXTWND *ptw)
 	if (ptw!=NULL) {
 		gtk_widget_set_sensitive(gtk_menu_get_attach_widget(GTK_MENU(
 								gtk_item_factory_get_widget(item_factory_menu,
-									_("<main>/Edit")))),TRUE);
+									"<main>/Edit"))),TRUE);
 		gtk_widget_set_sensitive(gtk_menu_get_attach_widget(GTK_MENU(
 								gtk_item_factory_get_widget(item_factory_menu,
-									_("<main>/Search")))),TRUE);
+									"<main>/Search"))),TRUE);
 		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
-									_("<main>/File/Close")),TRUE);
+									"<main>/File/Close"),TRUE);
 		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
-									_("<main>/File/Save")),TRUE);
+									"<main>/File/Save"),TRUE);
 		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
-									_("<main>/File/Save As...")),TRUE);
+									"<main>/File/Save As..."),TRUE);
 		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
-									_("<main>/File/Reload")),!ptw->create);
+									"<main>/File/Reload"),!ptw->create);
 #ifdef USE_GDKPIXBUF
 		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
-									_("<main>/File/Print...")),TRUE);
+									"<main>/File/Print..."),TRUE);
 #endif
 		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
-									_("<main>/File/Properties...")),TRUE);
+									"<main>/File/Properties..."),TRUE);
 		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
-									_("<main>/Edit/Undo")),ptw->undo!=NULL);
+									"<main>/Edit/Undo"),ptw->undo!=NULL);
 		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
-									_("<main>/Edit/Redo")),ptw->redo!=NULL);
+									"<main>/Edit/Redo"),ptw->redo!=NULL);
 		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
-									_("<main>/Edit/Cut")),ptw->select.x>=0);
+									"<main>/Edit/Cut"),ptw->select.x>=0);
 		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
-									_("<main>/Edit/Copy")),ptw->select.x>=0);
+									"<main>/Edit/Copy"),ptw->select.x>=0);
 		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
-									_("<main>/Edit/Delete")),ptw->select.x>=0);
+									"<main>/Edit/Delete"),ptw->select.x>=0);
 		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
-									_("<main>/Search/Next")),find_num>0);
+									"<main>/Search/Next"),find_num>0);
 		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
-									_("<main>/Search/Previous")),find_num>0);
+									"<main>/Search/Previous"),find_num>0);
 		gtk_widget_set_sensitive(toolbar_items[ 2].item,TRUE);
 		gtk_widget_set_sensitive(toolbar_items[ 4].item,TRUE);
 #ifdef USE_GDKPIXBUF
@@ -175,24 +175,24 @@ void set_menu_bar(TEXTWND *ptw)
 	} else {
 		gtk_widget_set_sensitive(gtk_menu_get_attach_widget(GTK_MENU(
 								gtk_item_factory_get_widget(item_factory_menu,
-									_("<main>/Edit")))),FALSE);
+									"<main>/Edit"))),FALSE);
 		gtk_widget_set_sensitive(gtk_menu_get_attach_widget(GTK_MENU(
 								gtk_item_factory_get_widget(item_factory_menu,
-									_("<main>/Search")))),FALSE);
+									"<main>/Search"))),FALSE);
 		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
-									_("<main>/File/Close")),FALSE);
+									"<main>/File/Close"),FALSE);
 		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
-									_("<main>/File/Save")),FALSE);
+									"<main>/File/Save"),FALSE);
 		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
-									_("<main>/File/Save As...")),FALSE);
+									"<main>/File/Save As..."),FALSE);
 		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
-									_("<main>/File/Reload")),FALSE);
+									"<main>/File/Reload"),FALSE);
 #ifdef USE_GDKPIXBUF
 		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
-									_("<main>/File/Print...")),FALSE);
+									"<main>/File/Print..."),FALSE);
 #endif
 		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
-									_("<main>/File/Properties...")),FALSE);
+									"<main>/File/Properties..."),FALSE);
 		gtk_widget_set_sensitive(toolbar_items[ 2].item,FALSE);
 		gtk_widget_set_sensitive(toolbar_items[ 4].item,FALSE);
 #ifdef USE_GDKPIXBUF
@@ -216,7 +216,7 @@ void set_menu_bar(TEXTWND *ptw)
 		gtk_widget_set_sensitive(toolbar_items[15].item,FALSE);
 #endif
 	}
-	menu=gtk_item_factory_get_widget(item_factory_menu,_("<main>/Window"));
+	menu=gtk_item_factory_get_widget(item_factory_menu,"<main>/Window");
 	glist=gtk_container_children(GTK_CONTAINER(menu));
 	gtk_widget_set_sensitive(gtk_menu_get_attach_widget(GTK_MENU(menu)),
 													g_list_length(glist)>0);
