@@ -28,6 +28,12 @@ typedef struct jmpdlg {
 } JMPDLG;
 
 
+/*	Ԥذư
+	 ptw,TXTɥ
+	line,(1...)														*/
+void jump_operation(TEXTWND *ptw,gint line);
+
+
 gboolean jump_dialog(JMPDLG *jmp);
 
 
