@@ -111,7 +111,7 @@ static void property_dialog_clicked_color_ok(GtkWidget *widget,
 		pixmap=gdk_pixmap_create_from_xpm_d(dialog->window,&mask,NULL,xpm);
 		g_free(xpm[1]);
 		gtk_clist_set_pixtext(GTK_CLIST(clist),i,0,
-												color_name[i],8,pixmap,mask);
+										gettext(color_name[i]),8,pixmap,mask);
 	}
 	property_dialog_ok_sensitive(NULL,NULL);
     gtk_widget_destroy(dialog_color);
@@ -296,7 +296,7 @@ static gboolean property_dialog_key_press(GtkWidget *widget,GdkEventKey *event,
 
 gboolean property_dialog(FTYPE *ft)
 {
-	gchar *xpm[18];
+	gchar *text,*xpm[18];
 	gint i;
 	guint key;
 	GdkPixmap *pixmap;
@@ -490,9 +490,10 @@ gboolean property_dialog(FTYPE *ft)
 			ft->color[i].red/256,ft->color[i].green/256,ft->color[i].blue/256);
 		pixmap=gdk_pixmap_create_from_xpm_d(window->window,&mask,NULL,xpm);
 		g_free(xpm[1]);
-		gtk_clist_append(GTK_CLIST(clist),&color_name[i]);
+		text=gettext(color_name[i]);
+		gtk_clist_append(GTK_CLIST(clist),&text);
 		gtk_clist_set_pixtext(GTK_CLIST(clist),i,0,
-												color_name[i],8,pixmap,mask);
+										gettext(color_name[i]),8,pixmap,mask);
 		color_list[i]=FALSE;
 	}
 	gtk_clist_set_column_width(GTK_CLIST(clist),0,
