@@ -85,6 +85,12 @@ GtkTargetEntry targets[3]={			/* Text maid󶡲ǽʥ쥯 */
 * ᥤؿ                                                                  *
 *                                                                             *
 ******************************************************************************/
+static gchar *menu_translate(const gchar *path,gpointer func_data)
+{
+   return gettext(path);
+}
+
+
 int main(int argc,char *argv[])
 {
 	gboolean *arg_files;
@@ -101,57 +107,57 @@ int main(int argc,char *argv[])
 	GtkStyle *style;
 	GtkWidget *menubar,*toolbar,*text,*handle,*vbox,*sub_menu,*menu_item;
 	GtkItemFactoryEntry menu_items[]={
-{N_("/_File"),                             NULL,         NULL,            0,"<Branch>"},
-{N_("/File/_New"),                         "<control>N", command_new,     0,"<Item>"},
-{N_("/File/_Open..."),                     "<control>O", command_open,    0,"<Item>"},
-{N_("/File/_Close"),                       "<control>W", command_close,   0,"<Item>"},
-{N_("/File/_Save"),                        "<control>S", command_save,    0,"<Item>"},
-{N_("/File/Save _As..."),                  NULL,         command_saveas,  0,"<Item>"},
-{N_("/File/_Reload"),                      "<control>R", command_reload,  0,"<Item>"},
-{N_("/File/Sep1"),                         NULL,         NULL,            0,"<Separator>"},
+{N_("/_File"),                       NULL,         NULL,            0,"<Branch>"},
+{N_("/File/_New"),                   "<control>N", command_new,     0,"<Item>"},
+{N_("/File/_Open..."),               "<control>O", command_open,    0,"<Item>"},
+{N_("/File/_Close"),                 "<control>W", command_close,   0,"<Item>"},
+{N_("/File/_Save"),                  "<control>S", command_save,    0,"<Item>"},
+{N_("/File/Save _As..."),            NULL,         command_saveas,  0,"<Item>"},
+{N_("/File/_Reload"),                "<control>R", command_reload,  0,"<Item>"},
+{N_("/File/Sep1"),                   NULL,         NULL,            0,"<Separator>"},
 #ifdef USE_GDKPIXBUF
-{N_("/File/_Print..."),                    "<control>P", command_print,   0,"<Item>"},
-{N_("/File/Sep2"),                         NULL,         NULL,            0,"<Separator>"},
+{N_("/File/_Print..."),              "<control>P", command_print,   0,"<Item>"},
+{N_("/File/Sep2"),                   NULL,         NULL,            0,"<Separator>"},
 #endif
-{N_("/File/Propert_ies..."),               "<alt>Return",command_property,0,"<Item>"},
-{N_("/File/Sep3"),                         NULL,         NULL,            0,"<Separator>"},
-{N_("/File/E_xit"),                        "<control>Q", command_exit,    0,"<Item>"},
-{N_("/_Edit"),                             NULL,         NULL,            0,"<Branch>"},
-{N_("/Edit/_Undo"),                        "<control>Z", command_undo,    0,"<Item>"},
-{N_("/Edit/_Redo"),                        "F4",         command_redo,    0,"<Item>"},
-{N_("/Edit/Sep1"),                         NULL,         NULL,            0,"<Separator>"},
-{N_("/Edit/Cu_t"),                         "<control>X", command_cut,     0,"<Item>"},
-{N_("/Edit/_Copy"),                        "<control>C", command_copy,    0,"<Item>"},
-{N_("/Edit/_Paste"),                       "<control>V", command_paste,   0,"<Item>"},
-{N_("/Edit/De_lete"),                      NULL,         command_delete,  0,"<Item>"},
-{N_("/Edit/Sep2"),                         NULL,         NULL,            0,"<Separator>"},
-{N_("/Edit/Return at Right _Margin"),      NULL,         command_margin,  0,"<Item>"},
-{N_("/Edit/Convert Ta_b to Space"),        NULL,         command_tab,     0,"<Item>"},
-{N_("/Edit/Sep3"),                         NULL,         NULL,            0,"<Separator>"},
-{N_("/Edit/_Character by _Value..."),      NULL,         command_valchr,  0,"<Item>"},
-{N_("/Edit/_Jump..."),                     "<control>J", command_jump,    0,"<Item>"},
-{N_("/Edit/Sep4"),                         NULL,         NULL,            0,"<Separator>"},
-{N_("/Edit/_All"),                         "<control>A", command_all,     0,"<Item>"},
-{N_("/_Search"),                           NULL,         NULL,            0,"<Branch>"},
-{N_("/Search/_Find..."),                   "<control>F", command_find,    0,"<Item>"},
-{N_("/Search/_Next"),                      "F3",         command_next,    0,"<Item>"},
-{N_("/Search/_Previous"),                  "<shift>F3",  command_next,    1,"<Item>"},
-{N_("/Search/_Replace..."),                "<control>H", command_replace, 0,"<Item>"},
-{N_("/_Option"),                           NULL,         NULL,            0,"<Branch>"},
-{N_("/Option/_Configuration..."),          NULL,         conf_dialog,     0,"<Item>"},
-{N_("/Option/File _Type..."),              NULL,         format_dialog,   0,"<Item>"},
-{N_("/_Window"),                           NULL,         NULL,            0,"<Branch>"},
-{N_("/_Help"),                             NULL,         NULL,            0,"<Branch>"},
-{N_("/Help/_About..."),                    NULL,         version_dialog,  0,"<Item>"}};
+{N_("/File/Propert_ies..."),         "<alt>Return",command_property,0,"<Item>"},
+{N_("/File/Sep3"),                   NULL,         NULL,            0,"<Separator>"},
+{N_("/File/E_xit"),                  "<control>Q", command_exit,    0,"<Item>"},
+{N_("/_Edit"),                       NULL,         NULL,            0,"<Branch>"},
+{N_("/Edit/_Undo"),                  "<control>Z", command_undo,    0,"<Item>"},
+{N_("/Edit/_Redo"),                  "F4",         command_redo,    0,"<Item>"},
+{N_("/Edit/Sep1"),                   NULL,         NULL,            0,"<Separator>"},
+{N_("/Edit/Cu_t"),                   "<control>X", command_cut,     0,"<Item>"},
+{N_("/Edit/_Copy"),                  "<control>C", command_copy,    0,"<Item>"},
+{N_("/Edit/_Paste"),                 "<control>V", command_paste,   0,"<Item>"},
+{N_("/Edit/De_lete"),                NULL,         command_delete,  0,"<Item>"},
+{N_("/Edit/Sep2"),                   NULL,         NULL,            0,"<Separator>"},
+{N_("/Edit/Return at Right _Margin"),NULL,         command_margin,  0,"<Item>"},
+{N_("/Edit/Convert Ta_b to Space"),  NULL,         command_tab,     0,"<Item>"},
+{N_("/Edit/Sep3"),                   NULL,         NULL,            0,"<Separator>"},
+{N_("/Edit/_Character by _Value..."),NULL,         command_valchr,  0,"<Item>"},
+{N_("/Edit/_Jump..."),               "<control>J", command_jump,    0,"<Item>"},
+{N_("/Edit/Sep4"),                   NULL,         NULL,            0,"<Separator>"},
+{N_("/Edit/_All"),                   "<control>A", command_all,     0,"<Item>"},
+{N_("/_Search"),                     NULL,         NULL,            0,"<Branch>"},
+{N_("/Search/_Find..."),             "<control>F", command_find,    0,"<Item>"},
+{N_("/Search/_Next"),                "F3",         command_next,    0,"<Item>"},
+{N_("/Search/_Previous"),            "<shift>F3",  command_next,    1,"<Item>"},
+{N_("/Search/_Replace..."),          "<control>H", command_replace, 0,"<Item>"},
+{N_("/_Option"),                     NULL,         NULL,            0,"<Branch>"},
+{N_("/Option/_Configuration..."),    NULL,         conf_dialog,     0,"<Item>"},
+{N_("/Option/File _Type..."),        NULL,         format_dialog,   0,"<Item>"},
+{N_("/_Window"),                     NULL,         NULL,            0,"<Branch>"},
+{N_("/_Help"),                       NULL,         NULL,            0,"<Branch>"},
+{N_("/Help/_About..."),              NULL,         version_dialog,  0,"<Item>"}};
 	GtkItemFactoryEntry popup_items[]={
-{N_("/_Undo"),                             "<control>Z", command_undo,    0,"<Item>"},
-{"/Sep1",                                  NULL,         NULL,            0,"<Separator>"},
-{N_("/Cu_t"),                              "<control>X", command_cut,     0,"<Item>"},
-{N_("/_Copy"),                             "<control>C", command_copy,    0,"<Item>"},
-{N_("/_Paste"),                            "<control>V", command_paste,   0,"<Item>"},
-{N_("/De_lete"),                           NULL,         command_delete,  0,"<Item>"},
-{"/Sep2",                                  NULL,         NULL,            0,"<Separator>"},
-{N_("/_All"),                              "<control>A", command_all,     0,"<Item>"}};
+{N_("/_Undo"),                       "<control>Z", command_undo,    0,"<Item>"},
+{"/Sep1",                            NULL,         NULL,            0,"<Separator>"},
+{N_("/Cu_t"),                        "<control>X", command_cut,     0,"<Item>"},
+{N_("/_Copy"),                       "<control>C", command_copy,    0,"<Item>"},
+{N_("/_Paste"),                      "<control>V", command_paste,   0,"<Item>"},
+{N_("/De_lete"),                     NULL,         command_delete,  0,"<Item>"},
+{"/Sep2",                            NULL,         NULL,            0,"<Separator>"},
+{N_("/_All"),                        "<control>A", command_all,     0,"<Item>"}};
 	/* Drag&Drop */
 	GtkTargetEntry drag_types[1]={{"text/uri-list",0,0}};
 	/* ޥɥ饤  */
@@ -481,7 +487,7 @@ int main(int argc,char *argv[])
 							else
 								str=g_strdup_printf("  -%c, --%s",
 											arg_opts[i].key, arg_opts[i].name);
-							g_print("%-26s %s\n",str,arg_opts[i].doc);
+							g_print("%-26s %s\n",str,gettext(arg_opts[i].doc));
 							g_free(str);
 						}
 						g_print("\n");
@@ -566,12 +572,16 @@ int main(int argc,char *argv[])
 	accel_group=gtk_accel_group_new();
 	item_factory_popup=gtk_item_factory_new(GTK_TYPE_MENU,
 														"<main>",accel_group);
+	gtk_item_factory_set_translate_func(item_factory_popup,menu_translate,
+																	NULL,NULL);
 	gtk_item_factory_create_items(item_factory_popup,
 			sizeof(popup_items)/sizeof(GtkItemFactoryEntry),popup_items,NULL);
 	/* ˥塼 */
 	accel_group=gtk_accel_group_new();
 	item_factory_menu=gtk_item_factory_new(GTK_TYPE_MENU_BAR,
 														"<main>",accel_group);
+	gtk_item_factory_set_translate_func(item_factory_menu,menu_translate,
+																	NULL,NULL);
 	gtk_item_factory_create_items(item_factory_menu,
 			sizeof(menu_items)/sizeof(GtkItemFactoryEntry),menu_items,NULL);
 	gtk_accel_group_attach(accel_group,GTK_OBJECT(window));
@@ -585,7 +595,7 @@ int main(int argc,char *argv[])
 			pixmap=gdk_pixmap_create_from_xpm_d(window->window,
 											&mask,NULL,toolbar_items[i].xpm);
 			toolbar_items[i].item=gtk_toolbar_append_item(GTK_TOOLBAR(toolbar),
-						NULL,toolbar_items[i].name,NULL,
+						NULL,_(toolbar_items[i].name),NULL,
 						gtk_pixmap_new(pixmap,mask),
 						toolbar_items[i].callback,toolbar_items[i].user_data);
 		}
@@ -609,7 +619,7 @@ int main(int argc,char *argv[])
 	gtk_box_pack_end(GTK_BOX(vbox),text,FALSE,FALSE,0);
 	gtk_container_add(GTK_CONTAINER(window),vbox);
 	/* ե */
-	sub_menu=gtk_item_factory_get_widget(item_factory_menu,_("<main>/File"));
+	sub_menu=gtk_item_factory_get_widget(item_factory_menu,"<main>/File");
 	for (i=0;i<history && hisfile[i]!=NULL;i++) {
 		menu_item=gtk_menu_item_new_with_label(hisfile[i]);
 		gtk_signal_connect(GTK_OBJECT(menu_item),"activate",
